Return the signed distance from point __p__ to a plane.

- Distance is positive if __p__ is in front of the plane, meaning that the plane normal is pointing towards __p__.
- Distance is negative if __p__ is behind the plane, meaning that the plane normal is pointing away from __p__.
- Distance is 0.0 if **p** is lying on the plane.